#include <QtDeclarative/qdeclarativeview.h>
#include <QtDeclarative/QDeclarativeContext>
#include <QtCore/QObject>
#include <QtCore/qvariant.h>
#include <QtGui/QApplication>
#include <QtCore/QCoreApplication>
#include <QtCore/QtGlobal>
#include <QtLocation/QGeoPositionInfoSource>
#include <QtLocation/QGeoSatelliteInfoSource>
#include <QtLocation/QGeoCoordinate>

extern "C" {
#include <location/location-gps-device.h>
#include <location/location-gpsd-control.h>
}

using namespace QtMobility;
/*
class aThread : public QThread
{
	Q_OBJECT
	public:
	    aThread(QObject *parent = 0);
	    void run();
	 
    QString x;
	    QString y;
	    QString z;
	 
public slots:
	    void updateCoords();
	    void processCoords(QString &data);
	 signals:
	   void deviceOrientation(QString x, QString y, QString z);
};
*/
class QDialGPS : public QApplication
{
    Q_OBJECT

	public:
	   QDialGPS(int argc, char** argv);
	   double angle;
	   double x;
	   double y;
	   double z;
	   double goalx;
	   double goaly;
	   double goalz;
	   bool connected;
	public Q_SLOTS:
	   Q_INVOKABLE double gangle();
	   Q_INVOKABLE void regoal();
	   Q_INVOKABLE double gx();
	   Q_INVOKABLE double gy();
	   Q_INVOKABLE double gz();
	   Q_INVOKABLE bool con();
	   Q_INVOKABLE QString gext();
};